@@ -12,7 +12,6 @@ time.sleep(0.01)
 """.lstrip()
 
 
-@pytest.mark.asyncio
 async def test_run(nextline: Nextline):
     assert nextline.state == "initialized"
 
@@ -35,12 +34,15 @@ async def control(nextline: Nextline):
     async for prompt_info in nextline.subscribe_prompt_info():
         if not prompt_info.open:
             continue
-        nextline.send_pdb_command(prompt_info.trace_no, "next")
+        nextline.send_pdb_command(
+            "next", prompt_info.prompt_no, prompt_info.trace_no
+        )
 
 
 @pytest.fixture
-def nextline(statement):
-    return Nextline(statement)
+async def nextline(statement):
+    async with Nextline(statement) as y:
+        yield y
 
 
 @pytest.fixture
