@@ -1,8 +1,10 @@
 import asyncio
-from typing import AsyncGenerator, Iterable, Any
+from typing import AsyncIterator, Iterable, TypeVar
+
+T = TypeVar("T")
 
 
-async def aiterable(iterable: Iterable) -> AsyncGenerator[Any, None]:
+async def aiterable(iterable: Iterable[T]) -> AsyncIterator[T]:
     '''Wrap iterable so can be used with "async for"'''
     for i in iterable:
         await asyncio.sleep(0)  # let other tasks run
